@@ -120,7 +120,7 @@ class Service:
                 with open (service_script, 'w') as f:
                     f.write (script)
             except PermissionError:
-                service_script = '{}.service'.format (name)
+                service_script = './{}.service'.format (name)
                 with open (service_script, 'w') as f:
                     f.write (script)
                 print ('install failed, you can install manually,')
